==> esup-canal-intranet-3.10.zip: CIntranet-3.10/db/esup-canal-intranet_postgre.sql <==
CREATE TABLE INT_ADMIN (
  ID_ENT varchar(240) NOT NULL default '',
  PRIMARY KEY  (ID_ENT)
);

INSERT INTO INT_ADMIN VALUES ('admin');


CREATE TABLE INT_DOCUMENT (
  ID_DOC int NOT NULL default '0',
  ID_INT varchar(20) NOT NULL default '',
  TYPE_DOC char(1) NOT NULL default '',
  ID_FOL int NOT NULL default '0',
  NAME_DOC text NOT NULL,
  DES_DOC text NOT NULL,
  FILE_DOC text default NULL,
  EXT_DOC varchar(16) default NULL,
  URL_DOC text default NULL,
  AUT_DOC varchar(240) NOT NULL default '',
  DATE_DOC varchar(8) NOT NULL default '',
  DATEVAL_DOC varchar(8) NOT NULL default '',
  ORDER_DOC int NOT NULL default '0',
  VALID_DOC char(1) NOT NULL default '',
  PENDM_DOC char(1) NOT NULL default '',
  PENDD_DOC char(1) NOT NULL default '',
  HIDDEN_DOC char(1) NOT NULL default '',
  ID_DOCMOD int NOT NULL default '0',
  PRIMARY KEY  (ID_DOC,ID_INT)
);

CREATE TABLE INT_ENTITIES (
  ID_INT varchar(20) NOT NULL default '',
  TYPE_ENT char(1) NOT NULL default '',
  ID_ENT varchar(240) NOT NULL default '',
  PRIMARY KEY  (ID_INT,TYPE_ENT,ID_ENT)
);

CREATE TABLE INT_FOLDER (
  ID_FOL int NOT NULL default '0',
  ID_INT varchar(20) NOT NULL default '',
  NAME_FOL text NOT NULL,
  ORDER_FOL int NOT NULL default '0',
  PARENT_FOL int NOT NULL default '0',
  DATE_FOL varchar(8) NOT NULL default '',
  PRIMARY KEY  (ID_FOL)
);

CREATE TABLE INT_GRANT (
  ID_FOL int NOT NULL default '0',
  TYPE_GRT int NOT NULL default '0',
  TYPE_ENT char(1) NOT NULL default '',
  ID_ENT varchar(240) NOT NULL default '',
  EXT_GRT char(1) NOT NULL default '',
  NOT_GRT char(1) NOT NULL default '',
  PRIMARY KEY  (ID_FOL,TYPE_GRT,TYPE_ENT,ID_ENT)
);

CREATE TABLE INT_INTRANET (
  ID_INT varchar(20) NOT NULL default '',
  NAME_INT text NOT NULL,
  ORDER_INT int NOT NULL default '0',
  RES_INT varchar(20) NOT NULL default '',
  FOL_INT int NOT NULL default '0',
  ID_DOC int NOT NULL default '0',
  PRIMARY KEY  (ID_INT)
);

CREATE TABLE INT_KEY (
  NAME_KEY varchar(16) NOT NULL default '',
  VALUE_KEY int NOT NULL default '0',
  PRIMARY KEY  (NAME_KEY)
);

INSERT INTO INT_KEY VALUES ('INT_FOLDER', 1);

CREATE TABLE INT_MIME (
  EXT_MIME varchar(16) NOT NULL default '',
  TYPE_MIME text NOT NULL,
  PRIMARY KEY  (EXT_MIME)
);

INSERT INTO INT_MIME VALUES ('.doc', 'application/msword');
INSERT INTO INT_MIME VALUES ('.gz', 'application/x-gzip');
INSERT INTO INT_MIME VALUES ('.htm', 'text/html');
INSERT INTO INT_MIME VALUES ('.html', 'text/html');
INSERT INTO INT_MIME VALUES ('.pdf', 'application/pdf');
INSERT INTO INT_MIME VALUES ('.ppt', 'application/mspowerpoint');
INSERT INTO INT_MIME VALUES ('.rar', 'application/rar');
INSERT INTO INT_MIME VALUES ('.tar', 'application/x-tar');
INSERT INTO INT_MIME VALUES ('.txt', 'text/plain');
INSERT INTO INT_MIME VALUES ('.xls', 'application/msexcel');
INSERT INTO INT_MIME VALUES ('.zip', 'application/zip');

==> esup-canal-intranet-3.20.zip: CIntranet-3.20/db/esup-canal-intranet_postgre.sql <==
CREATE TABLE INT_ADMIN (
  ID_ENT varchar(240) NOT NULL default '',
  PRIMARY KEY  (ID_ENT)
);

INSERT INTO INT_ADMIN VALUES ('admin');


CREATE TABLE INT_DOCUMENT (
  ID_DOC int NOT NULL default '0',
  ID_INT varchar(20) NOT NULL default '',
  TYPE_DOC char(1) NOT NULL default '',
  ID_FOL int NOT NULL default '0',
  NAME_DOC text NOT NULL,
  DES_DOC text NOT NULL,
  FILE_DOC text default NULL,
  EXT_DOC varchar(16) default NULL,
  URL_DOC text default NULL,
  AUT_DOC varchar(240) NOT NULL default '',
  DATE_DOC varchar(8) NOT NULL default '',
  DATEVAL_DOC varchar(8) NOT NULL default '',
  ORDER_DOC int NOT NULL default '0',
  VALID_DOC char(1) NOT NULL default '',
  PENDM_DOC char(1) NOT NULL default '',
  PENDD_DOC char(1) NOT NULL default '',
  HIDDEN_DOC char(1) NOT NULL default '',
  ID_DOCMOD int NOT NULL default '0',
  PRIMARY KEY  (ID_DOC,ID_INT)
);

CREATE TABLE INT_ENTITIES (
  ID_INT varchar(20) NOT NULL default '',
  TYPE_ENT char(1) NOT NULL default '',
  ID_ENT varchar(240) NOT NULL default '',
  PRIMARY KEY  (ID_INT,TYPE_ENT,ID_ENT)
);

CREATE TABLE INT_FOLDER (
  ID_FOL int NOT NULL default '0',
  ID_INT varchar(20) NOT NULL default '',
  NAME_FOL text NOT NULL,
  ORDER_FOL int NOT NULL default '0',
  PARENT_FOL int NOT NULL default '0',
  DATE_FOL varchar(8) NOT NULL default '',
  NOT_FOL varchar(1) NOT NULL default '0',
  MAIL_FOL text NOT NULL default '',
  PRIMARY KEY  (ID_FOL)
);

CREATE TABLE INT_GRANT (
  ID_FOL int NOT NULL default '0',
  TYPE_GRT int NOT NULL default '0',
  TYPE_ENT char(1) NOT NULL default '',
  ID_ENT varchar(240) NOT NULL default '',
  EXT_GRT char(1) NOT NULL default '',
  NOT_GRT char(1) NOT NULL default '',
  PRIMARY KEY  (ID_FOL,TYPE_GRT,TYPE_ENT,ID_ENT)
);

CREATE TABLE INT_INTRANET (
  ID_INT varchar(20) NOT NULL default '',
  NAME_INT text NOT NULL,
  DES_INT` text NOT NULL default '',  
  ORDER_INT int NOT NULL default '0',
  RES_INT varchar(20) NOT NULL default '',
  FOL_INT int NOT NULL default '0',
  ID_DOC int NOT NULL default '0',
  PRIMARY KEY  (ID_INT)
);

CREATE TABLE INT_KEY (
  NAME_KEY varchar(16) NOT NULL default '',
  VALUE_KEY int NOT NULL default '0',
  PRIMARY KEY  (NAME_KEY)
);

INSERT INTO INT_KEY VALUES ('INT_FOLDER', 1);

CREATE TABLE INT_MIME (
  EXT_MIME varchar(16) NOT NULL default '',
  TYPE_MIME text NOT NULL,
  PRIMARY KEY  (EXT_MIME)
);

INSERT INTO INT_MIME VALUES ('.doc', 'application/msword');
INSERT INTO INT_MIME VALUES ('.gz', 'application/x-gzip');
INSERT INTO INT_MIME VALUES ('.htm', 'text/html');
INSERT INTO INT_MIME VALUES ('.html', 'text/html');
INSERT INTO INT_MIME VALUES ('.pdf', 'application/pdf');
INSERT INTO INT_MIME VALUES ('.ppt', 'application/mspowerpoint');
INSERT INTO INT_MIME VALUES ('.rar', 'application/rar');
INSERT INTO INT_MIME VALUES ('.tar', 'application/x-tar');
INSERT INTO INT_MIME VALUES ('.txt', 'text/plain');
INSERT INTO INT_MIME VALUES ('.xls', 'application/msexcel');
INSERT INTO INT_MIME VALUES ('.zip', 'application/zip');
